@@ -1150,15 +1150,29 @@ size_t stress_get_max_file_limit(void)
 size_t stress_get_file_limit(void)
 {
 	struct rlimit rlim;
-	size_t i, opened = 0, max = 65536;	/* initial guess */
+	size_t i, last_opened, opened = 0, max = 65536;	/* initial guess */
 
 	if (!getrlimit(RLIMIT_NOFILE, &rlim))
 		max = (size_t)rlim.rlim_cur;
 
+	last_opened = 0;
+
 	/* Determine max number of free file descriptors we have */
 	for (i = 0; i < max; i++) {
-		if (fcntl((int)i, F_GETFL) > -1)
+		if (fcntl((int)i, F_GETFL) > -1) {
 			opened++;
+			last_opened = i;
+		} else {
+			/*
+			 *  Hack: Over 250 contiguously closed files
+			 *  most probably indicates we're at the point
+			 *  were no more opened file descriptors are
+			 *  going to be found, so bail out rather then
+			 *  scanning for any more opened files
+			 */
+			if (i - last_opened > 250)
+				break;
+		}
 	}
 	return max - opened;
 }
@@ -1682,29 +1696,32 @@ char *stress_const_optdup(const char *opt)
  */
 size_t stress_text_addr(char **start, char **end)
 {
-#if defined(__APPLE__)
-        extern void *get_etext(void);
-        intptr_t text_start = (intptr_t)get_etext();
+#if defined(HAVE_EXECUTABLE_START)
+	extern char __executable_start;
+	intptr_t text_start = (intptr_t)&__executable_start;
+#elif defined(__APPLE__)
+        extern char _mh_execute_header;
+        intptr_t text_start = (intptr_t)&_mh_execute_header;
 #elif defined(__OpenBSD__)
         extern char _start[];
         intptr_t text_start = (intptr_t)&_start[0];
 #elif defined(__TINYC__)
-        extern char _etext;
-        intptr_t text_start = (intptr_t)&_etext;
+        extern char _start;
+        intptr_t text_start = (intptr_t)&_start;
 #else
-        extern char etext;
-        intptr_t text_start = (intptr_t)&etext;
+        extern char _start;
+        intptr_t text_start = (intptr_t)&_start;
 #endif
 
 #if defined(__APPLE__)
-        extern void *get_edata(void);
-        intptr_t text_end = (intptr_t)get_edata();
+        extern void *get_etext(void);
+        intptr_t text_end = (intptr_t)get_etext();
 #elif defined(__TINYC__)
-        extern char _edata;
-        intptr_t text_end = (intptr_t)&_edata;
+        extern char _etext;
+        intptr_t text_end = (intptr_t)&_etext;
 #else
-        extern char edata;
-        intptr_t text_end = (intptr_t)&edata;
+        extern char etext;
+        intptr_t text_end = (intptr_t)&etext;
 #endif
         const size_t text_len = text_end - text_start;
 
@@ -1739,7 +1756,7 @@ bool stress_is_dev_tty(const int fd)
 }
 
 /*
- *  stress_dirent_list_free
+ *  stress_dirent_list_free()
  *	free dirent list
  */
 void stress_dirent_list_free(struct dirent **dlist, const int n)
@@ -1755,6 +1772,28 @@ void stress_dirent_list_free(struct dirent **dlist, const int n)
 	}
 }
 
+/*
+ *  stress_dirent_list_prune()
+ *	remove . and .. files from directory list
+ */
+int stress_dirent_list_prune(struct dirent **dlist, const int n)
+{
+	int i, j;
+
+	for (i = 0, j = 0; i < n; i++) {
+		if (dlist[i]) {
+			if (stress_is_dot_filename(dlist[i]->d_name)) {
+				free(dlist[i]);
+				dlist[i] = NULL;
+			} else {
+				dlist[j] = dlist[i];
+				j++;
+			}
+		}
+	}
+	return j;
+}
+
 /*
  *  stress_warn_once_hash()
  *	computes a hash for a filename and a line and stores it,
@@ -1981,7 +2020,7 @@ int stress_kernel_release(const int major, const int minor, const int patchlevel
 
 /*
  *  stress_get_kernel_release()
- *	return kernel relase number in base 100, e.g.
+ *	return kernel release number in base 100, e.g.
  *	 4.15.2 -> 401502, return -1 if failed.
  */
 int stress_get_kernel_release(void)
@@ -2002,6 +2041,70 @@ int stress_get_kernel_release(void)
 #endif
 }
 
+/*
+ *  stress_get_unused_pid_racy()
+ *	try to find an unused pid. This is racy and may actually
+ *	return pid that is unused at test time but will become
+ *	used by the time the pid is accessed.
+ */
+pid_t stress_get_unused_pid_racy(const bool fork_test)
+{
+	char buf[64];
+#if defined(PID_MAX_LIMIT)
+	pid_t max_pid = PID_MAX_LIMIT;
+#elif defined(PID_MAX)
+	pid_t max_pid = PID_MAX;
+#elif defined(PID_MAX_DEFAULT)
+	pid_t max_pid = PID_MAX_DEFAULT;
+#else
+	pid_t max_pid = 32767;
+#endif
+	int i;
+	pid_t pid;
+
+	(void)memset(buf, 0, sizeof(buf));
+	if (system_read("/proc/sys/kernel/pid_max", buf, sizeof(buf) - 1) > 0) {
+		max_pid = atoi(buf);
+	}
+	if (max_pid < 1024)
+		max_pid = 1024;
+
+	/*
+	 *  Create a child, terminate it, use this pid as an unused
+	 *  pid. Slow but should be OK if system doesn't recycle PIDs
+	 *  quickly.
+	 */
+	if (fork_test) {
+		pid = fork();
+		if (pid == 0) {
+			_exit(0);
+		} else if (pid > 0) {
+			int status, ret;
+
+			ret = waitpid(pid, &status, 0);
+			if ((ret == pid) &&
+			    ((kill(pid, 0) < 0) && (errno == ESRCH))) {
+				return pid;
+			}
+		}
+	}
+
+	/*
+	 *  Make a random PID guess.
+	 */
+	for (i = 0; i < 20; i++) {
+		pid = (stress_mwc32() % (max_pid - 1023)) + 1023;
+
+		if ((kill(pid, 0) < 0) && (errno == ESRCH))
+			return pid;
+	}
+
+	/*
+	 *  Give up.
+	 */
+	return max_pid;
+}
+
 /*
  *  stress_read_fdinfo()
  *	read the fdinfo for a specific pid's fd, Linux only
