@@ -199,7 +199,6 @@ static int stress_file_ioctl(const stress_args_t *args)
 #endif
 
 /* Disable this at the moment, it is fragile */
-#if 0
 #if defined(FIFREEZE) && defined(FITHAW)
 		{
 			ret = ioctl(fd, FIFREEZE);
@@ -210,7 +209,6 @@ static int stress_file_ioctl(const stress_args_t *args)
 			exercised++;
 		}
 #endif
-#endif
 
 #if defined(FIGETBSZ)
 		{
@@ -297,6 +295,7 @@ static int stress_file_ioctl(const stress_args_t *args)
 		}
 #endif
 
+
 #if defined(FIONWRITE)
 		{
 			int isz = 0;
@@ -308,11 +307,59 @@ static int stress_file_ioctl(const stress_args_t *args)
 		}
 #endif
 
+#if defined(FS_IOC_GETVERSION)
+		{
+			int ver;
+
+			ret = ioctl(fd, FS_IOC_GETVERSION, &ver);
+			(void)ret;
+
+			exercised++;
+		}
+#endif
+
+#if defined(_IOW) && defined(__linux__)
+
+/*
+ *  These will eventually be in linux/falloc.h for libc, but
+ *  define a shim version for now.
+ */
+struct shim_space_resv {
+	int16_t		l_type;
+	int16_t		l_whence;
+	int64_t		l_start;
+	int64_t		l_len;
+	int32_t		l_sysid;
+	uint32_t	l_pid;
+	int32_t		l_pad[4];
+};
+
+#if !defined(FS_IOC_RESVSP) && defined(_IOW)
+#define FS_IOC_RESVSP		_IOW('X', 40, struct shim_space_resv)
+#endif
+#if !defined(FS_IOC_UNRESVSP) && defined(_IOW)
+#define FS_IOC_UNRESVSP		_IOW('X', 41, struct shim_space_resv)
+#endif
+#if !defined(FS_IOC_RESVSP64) && defined(_IOW)
+#define FS_IOC_RESVSP64		_IOW('X', 42, struct shim_space_resv)
+#endif
+#if !defined(FS_IOC_UNRESVSP64) && defined(_IOW)
+#define FS_IOC_UNRESVSP64	_IOW('X', 43, struct shim_space_resv)
+#endif
+#if !defined(FS_IOC_ZERO_RANGE) && defined(_IOW)
+#define FS_IOC_ZERO_RANGE	_IOW('X', 57, struct shim_space_resv)
+#endif
+
 #if defined(FS_IOC_RESVSP)
 		{
-			unsigned long isz = file_sz * 2;
+			struct shim_space_resv r;
 
-			ret = ioctl(fd, FS_IOC_RESVP, &isz);
+			(void)memset(&r, 0, sizeof(r));
+			r.l_whence = SEEK_SET;
+			r.l_start = (int64_t)0;
+			r.l_len = (int64_t)file_sz * 2;
+
+			ret = ioctl(fd, FS_IOC_RESVSP, &r);
 			(void)ret;
 
 			exercised++;
@@ -321,15 +368,70 @@ static int stress_file_ioctl(const stress_args_t *args)
 
 #if defined(FS_IOC_RESVSP64)
 		{
-			unsigned long isz = file_sz * 2;
+			struct shim_space_resv r;
 
-			ret = ioctl(fd, FS_IOC_RESVP64, &isz);
+			(void)memset(&r, 0, sizeof(r));
+			r.l_whence = SEEK_SET;
+			r.l_start = (int64_t)0;
+			r.l_len = (int64_t)file_sz * 2;
+
+			ret = ioctl(fd, FS_IOC_RESVSP64, &r);
 			(void)ret;
 
 			exercised++;
 		}
 #endif
 
+#if defined(FS_IOC_UNRESVSP)
+		{
+			struct shim_space_resv r;
+
+			(void)memset(&r, 0, sizeof(r));
+			r.l_whence = SEEK_SET;
+			r.l_start = (int64_t)file_sz;
+			r.l_len = (int64_t)file_sz * 2;
+
+			ret = ioctl(fd, FS_IOC_UNRESVSP, &r);
+			(void)ret;
+
+			exercised++;
+		}
+#endif
+
+#if defined(FS_IOC_UNRESVSP64)
+		{
+			struct shim_space_resv r;
+
+			(void)memset(&r, 0, sizeof(r));
+			r.l_whence = SEEK_SET;
+			r.l_start = (int64_t)file_sz;
+			r.l_len = (int64_t)file_sz * 2;
+
+			ret = ioctl(fd, FS_IOC_UNRESVSP64, &r);
+			(void)ret;
+
+			exercised++;
+		}
+#endif
+
+#if defined(FS_IOC_ZERO_RANGE)
+		{
+			struct shim_space_resv r;
+
+			(void)memset(&r, 0, sizeof(r));
+			r.l_whence = SEEK_SET;
+			r.l_start = (int64_t)0;
+			r.l_len = (int64_t)file_sz / 2;
+
+			ret = ioctl(fd, FS_IOC_ZERO_RANGE, &r);
+			(void)ret;
+
+			exercised++;
+		}
+#endif
+
+#endif
+
 #if defined(FIBMAP)
 		{
 			int block = 0;
