@@ -32,6 +32,7 @@
 		break;			\
 
 #define GIDS_MAX 	(1024)
+#define MOUNTS_MAX	(256)
 
 static const stress_help_t help[] = {
 	{ NULL,	"get N",	"start N workers exercising the get*() system calls" },
@@ -134,6 +135,8 @@ static void MLOCKED_TEXT stress_segv_handler(int num)
  */
 static int stress_get(const stress_args_t *args)
 {
+	char *mnts[MOUNTS_MAX];
+	size_t mounts_max;
 	const bool verify = (g_opt_flags & OPT_FLAGS_VERIFY);
 #if defined(HAVE_SYS_TIMEX_H)
 #if defined(HAVE_ADJTIMEX) || defined(HAVE_ADJTIME)
@@ -144,6 +147,8 @@ static int stress_get(const stress_args_t *args)
 	if (stress_sighandler(args->name, SIGSEGV, stress_segv_handler, NULL) < 0)
 		return EXIT_NO_RESOURCE;
 
+	mounts_max = stress_mount_get(mnts, MOUNTS_MAX);
+
 	do {
 		char path[PATH_MAX];
 		char *ptr;
@@ -271,6 +276,13 @@ static int stress_get(const stress_args_t *args)
 		pid = getpgid(mypid);
 		(void)pid;
 		check_do_run();
+
+		/*
+		 *  Exercise with an possibly invalid pid
+		 */
+		pid = stress_get_unused_pid_racy(false);
+		pid = getpgid(pid);
+		(void)pid;
 #endif
 
 #if defined(HAVE_GETPRIORITY)
@@ -280,6 +292,8 @@ static int stress_get(const stress_args_t *args)
 		 */
 		(void)getpriority(INT_MIN, 0);
 		(void)getpriority(INT_MAX, 0);
+		pid = stress_get_unused_pid_racy(false);
+		(void)getpriority(pid, 0);
 
 		for (i = 0; i < SIZEOF_ARRAY(priorities); i++) {
 			errno = 0;
@@ -347,6 +361,8 @@ static int stress_get(const stress_args_t *args)
 #if defined(HAVE_PRLIMIT) && NEED_GLIBC(2,13,0) && defined(EOVERFLOW)
 		/* Invalid prlimit syscall and ignoring failure */
 		(void)prlimit(mypid, INT_MAX, NULL, &rlim);
+		pid = stress_get_unused_pid_racy(false);
+		(void)prlimit(pid, INT_MAX, NULL, &rlim);
 
 		for (i = 0; i < SIZEOF_ARRAY(rlimits); i++) {
 			struct rlimit rlims[2];
@@ -365,6 +381,9 @@ static int stress_get(const stress_args_t *args)
 					pr_fail("%s: prlimit(%d, %zu, ..) failed, errno=%d (%s)\n",
 						args->name, mypid, i, errno, strerror(errno));
 			}
+
+			/* Exercise invalid pids */
+			(void)prlimit(pid, rlimits[i], NULL, &rlims[0]);
 			check_do_run();
 		}
 #endif
@@ -409,6 +428,9 @@ static int stress_get(const stress_args_t *args)
 		if (verify && (ret < 0))
 			pr_fail("%s: getsid failed, errno=%d (%s)\n",
 				args->name, errno, strerror(errno));
+		pid = stress_get_unused_pid_racy(false);
+		ret = getsid(pid);
+		(void)ret;
 		check_do_run();
 #endif
 
@@ -588,9 +610,36 @@ static int stress_get(const stress_args_t *args)
 				}
 			}
 		}
+#if defined(HAVE_SYS_VFS_H) &&	\
+    defined(HAVE_STATFS) &&	\
+    defined(__linux__)
+		for (i = 0; i < mounts_max; i++) {
+			struct statfs buf;
+			int fd;
+
+			(void)statfs(mnts[i], &buf);
+
+			fd = open(mnts[i], O_RDONLY);
+			if (fd >= 0) {
+				(void)fstatfs(fd, &buf);
+				(void)close(fd);
+			}
+		}
+#endif
+
+#if defined(HAVE_SYS_STATVFS_H)
+		for (i = 0; i < mounts_max; i++) {
+			struct statvfs buf;
+
+			statvfs(mnts[i], &buf);
+		}
+#endif
+
 		inc_counter(args);
 	} while (keep_stressing());
 
+	stress_mount_free(mnts, mounts_max);
+
 	return EXIT_SUCCESS;
 }
 
