@@ -70,6 +70,12 @@ static const getrandom_flags_t getrandom_flags[] = {
 #if defined(GRND_NONBLOCK) && defined(__linux__)
 	GETRANDOM_FLAG_INFO(GRND_NONBLOCK),
 #endif
+#if defined(GRND_RANDOM) && defined(__linux__)
+	GETRANDOM_FLAG_INFO(GRND_RANDOM),
+#endif
+#if defined(GRND_INSECURE) && defined(__linux__)
+	GETRANDOM_FLAG_INFO(GRND_INSECURE),
+#endif
 #if defined(GRND_NONBLOCK) && defined(GRND_RANDOM) && defined(__linux__)
 	GETRANDOM_FLAG_INFO(GRND_NONBLOCK | GRND_RANDOM),
 #endif
@@ -96,7 +102,9 @@ static int stress_getrandom(const stress_args_t *args)
 
 			ret = shim_getrandom(buffer, sizeof(buffer), getrandom_flags[i].flag);
 			if (ret < 0) {
-				if ((errno == EAGAIN) || (errno == EINTR))
+				if ((errno == EAGAIN) ||
+				    (errno == EINTR) ||
+				    (errno == EINVAL))
 					continue;
 				if (errno == ENOSYS) {
 					/* Should not happen.. */
