@@ -61,7 +61,8 @@ static void stress_iomix_wr_seq_bursts(
 		posn = stress_mwc64() % iomix_bytes;
 		ret = lseek(fd, posn, SEEK_SET);
 		if (ret < 0) {
-			pr_fail_err("seek");
+			pr_fail("%s: lseek failed, errno=%d (%s)\n",
+				args->name, errno, strerror(errno));
 			return;
 		}
 		for (i = 0; (i < n) && (posn < iomix_bytes); i++) {
@@ -74,7 +75,8 @@ static void stress_iomix_wr_seq_bursts(
 			rc = write(fd, buffer, len);
 			if (rc < 0) {
 				if (errno != EPERM) {
-					pr_fail_err("write");
+					pr_fail("%s: write failed, errno=%d (%s)\n",
+						args->name, errno, strerror(errno));
 					return;
 				}
 			}
@@ -112,7 +114,8 @@ static void stress_iomix_wr_rnd_bursts(
 			posn = stress_mwc64() % iomix_bytes;
 			ret = lseek(fd, posn, SEEK_SET);
 			if (ret < 0) {
-				pr_fail_err("seek");
+				pr_fail("%s: lseek failed, errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 				return;
 			}
 
@@ -120,7 +123,8 @@ static void stress_iomix_wr_rnd_bursts(
 			rc = write(fd, buffer, len);
 			if (rc < 0) {
 				if (errno != EPERM) {
-					pr_fail_err("write");
+					pr_fail("%s: write failed, errno=%d (%s)\n",
+						args->name, errno, strerror(errno));
 					return;
 				}
 			}
@@ -149,7 +153,8 @@ static void stress_iomix_wr_seq_slow(
 
 		ret = lseek(fd, 0, SEEK_SET);
 		if (ret < 0) {
-			pr_fail_err("seek");
+			pr_fail("%s: lseek failed, errno=%d (%s)\n",
+				args->name, errno, strerror(errno));
 			return;
 		}
 		while (posn < iomix_bytes) {
@@ -162,7 +167,8 @@ static void stress_iomix_wr_seq_slow(
 			rc = write(fd, buffer, len);
 			if (rc < 0) {
 				if (errno != EPERM) {
-					pr_fail_err("write");
+					pr_fail("%s: write failed, errno=%d (%s)\n",
+						args->name, errno, strerror(errno));
 					return;
 				}
 			}
@@ -193,7 +199,8 @@ static void stress_iomix_rd_seq_bursts(
 		posn = stress_mwc64() % iomix_bytes;
 		ret = lseek(fd, posn, SEEK_SET);
 		if (ret < 0) {
-			pr_fail_err("seek");
+			pr_fail("%s: lseek failed, errno=%d (%s)\n",
+				args->name, errno, strerror(errno));
 			return;
 		}
 #if defined(HAVE_POSIX_FADVISE)
@@ -206,7 +213,8 @@ static void stress_iomix_rd_seq_bursts(
 
 			rc = read(fd, buffer, len);
 			if (rc < 0) {
-				pr_fail_err("read");
+				pr_fail("%s: read failed, errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 				return;
 			}
 			posn += rc;
@@ -246,13 +254,15 @@ static void stress_iomix_rd_rnd_bursts(
 #endif
 			ret = lseek(fd, posn, SEEK_SET);
 			if (ret < 0) {
-				pr_fail_err("seek");
+				pr_fail("%s: lseek failed, errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 				return;
 			}
 
 			rc = read(fd, buffer, len);
 			if (rc < 0) {
-				pr_fail_err("read");
+				pr_fail("%s: read failed, errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 				return;
 			}
 			if (!keep_stressing())
@@ -279,7 +289,8 @@ static void stress_iomix_rd_seq_slow(
 
 		ret = lseek(fd, 0, SEEK_SET);
 		if (ret < 0) {
-			pr_fail_err("seek");
+			pr_fail("%s: lseek failed, errno=%d (%s)\n",
+				args->name, errno, strerror(errno));
 			return;
 		}
 		while (posn < iomix_bytes) {
@@ -292,7 +303,8 @@ static void stress_iomix_rd_seq_slow(
 #endif
 			rc = read(fd, buffer, len);
 			if (rc < 0) {
-				pr_fail_err("read");
+				pr_fail("%s: read failed, errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 				return;
 			}
 			(void)shim_usleep(333333);
@@ -397,7 +409,7 @@ static void stress_iomix_rd_wr_mmap(
 			if (mmaps[i] != MAP_FAILED) {
 				size_t j;
 				uint64_t sum = 0;
-				uint8_t *buffer =  (uint8_t *)mmaps[i];
+				uint8_t *buffer = (uint8_t *)mmaps[i];
 
 				/* Force page data to be read */
 				for (j = 0; j < page_size; j++)
@@ -431,7 +443,8 @@ static void stress_iomix_wr_bytes(
 
 		ret = lseek(fd, 0, SEEK_SET);
 		if (ret < 0) {
-			pr_fail_err("seek");
+			pr_fail("%s: lseek failed, errno=%d (%s)\n",
+				args->name, errno, strerror(errno));
 			return;
 		}
 		while (posn < iomix_bytes) {
@@ -441,7 +454,8 @@ static void stress_iomix_wr_bytes(
 			rc = write(fd, buffer, sizeof(buffer));
 			if (rc < 0) {
 				if (errno != EPERM) {
-					pr_fail_err("write");
+					pr_fail("%s: write failed, errno=%d (%s)\n",
+						args->name, errno, strerror(errno));
 					return;
 			}	}
 			(void)shim_usleep(1000);
@@ -471,14 +485,16 @@ static void stress_iomix_rd_bytes(
 
 			ret = lseek(fd, posn, SEEK_SET);
 			if (ret < 0) {
-				pr_fail_err("seek");
+				pr_fail("%s: lseek failed, errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 				return;
 			}
 
 			rc = read(fd, buffer, sizeof(buffer));
 			if (rc < 0) {
 				if (errno != EPERM) {
-					pr_fail_err("write");
+					pr_fail("%s: write failed, errno=%d (%s)\n",
+						args->name, errno, strerror(errno));
 					return;
 				}
 			}
@@ -549,6 +565,7 @@ static void stress_iomix_inode_flags(
 	const off_t iomix_bytes)
 {
 	(void)args;
+	(void)fd;
 	(void)iomix_bytes;
 
 	do {
@@ -669,7 +686,8 @@ static int stress_iomix(const stress_args_t *args)
 	counters = (void *)mmap(NULL, sz, PROT_READ | PROT_WRITE,
 			MAP_SHARED | MAP_ANONYMOUS, -1, 0);
 	if (counters == MAP_FAILED) {
-		pr_fail_dbg("mmap");
+		pr_fail("%s: mmap failed, errno=%d (%s)\n",
+			args->name, errno, strerror(errno));
 		return EXIT_NO_RESOURCE;
 	}
 
@@ -695,7 +713,8 @@ static int stress_iomix(const stress_args_t *args)
 		filename, sizeof(filename), stress_mwc32());
 	if ((fd = open(filename, O_CREAT | O_RDWR | O_SYNC, S_IRUSR | S_IWUSR)) < 0) {
 		ret = exit_status(errno);
-		pr_fail_err("open");
+		pr_fail("%s: open %s failed, errno=%d (%s)\n",
+			args->name, filename, errno, strerror(errno));
 		goto unmap;
 	}
 	(void)unlink(filename);
@@ -710,7 +729,8 @@ static int stress_iomix(const stress_args_t *args)
 			ret = EXIT_NO_RESOURCE;
 		} else {
 			ret = EXIT_FAILURE;
-			pr_fail_err("fallocate");
+			pr_fail("%s: fallocate failed, errno=%d (%s)\n",
+				args->name, errno, strerror(errno));
 		}
 		goto tidy;
 	}
@@ -719,22 +739,16 @@ static int stress_iomix(const stress_args_t *args)
 	(void)memset(counters, 0, sz);
 
 	for (i = 0; i < SIZEOF_ARRAY(iomix_funcs); i++) {
-		const stress_args_t tmp_args = {
-			.counter = &counters[i],
-			.name = args->name,
-			.max_ops = args->max_ops,
-			.instance = args->instance,
-			.num_instances = args->num_instances,
-			.pid = args->pid,
-			.ppid = args->ppid,
-			.page_size = args->page_size
-		};
+		stress_args_t tmp_args = *args;
+
+		tmp_args.counter = &counters[i];
 
 		pids[i] = fork();
 		if (pids[i] < 0) {
 			goto reap;
 		} else if (pids[i] == 0) {
 			/* Child */
+			(void)sched_settings_apply(true);
 			iomix_funcs[i](&tmp_args, fd, iomix_bytes);
 			_exit(EXIT_SUCCESS);
 		}
