@@ -589,6 +589,7 @@ static const struct option long_options[] = {
 	{ "opcode-ops",	1,	0,	OPT_opcode_ops },
 	{ "opcode-method",1,	0,	OPT_opcode_method },
 	{ "open",	1,	0,	OPT_open },
+	{ "open-fd",	0,	0,	OPT_open_fd },
 	{ "open-ops",	1,	0,	OPT_open_ops },
 	{ "page-in",	0,	0,	OPT_page_in },
 	{ "parallel",	1,	0,	OPT_all },
@@ -856,16 +857,18 @@ static const struct option long_options[] = {
 	{ "udp-flood",	1,	0,	OPT_udp_flood },
 	{ "udp-flood-domain",1,	0,	OPT_udp_flood_domain },
 	{ "udp-flood-ops",1,	0,	OPT_udp_flood_ops },
+	{ "unshare",	1,	0,	OPT_unshare },
+	{ "unshare-ops",1,	0,	OPT_unshare_ops },
+	{ "uprobe",	1,	0,	OPT_uprobe },
+	{ "uprobe-ops",	1,	0,	OPT_uprobe_ops },
+	{ "urandom",	1,	0,	OPT_urandom },
+	{ "urandom-ops",1,	0,	OPT_urandom_ops },
 	{ "userfaultfd",1,	0,	OPT_userfaultfd },
 	{ "userfaultfd-ops",1,	0,	OPT_userfaultfd_ops },
 	{ "userfaultfd-bytes",1,0,	OPT_userfaultfd_bytes },
 	{ "utime",	1,	0,	OPT_utime },
 	{ "utime-ops",	1,	0,	OPT_utime_ops },
 	{ "utime-fsync",0,	0,	OPT_utime_fsync },
-	{ "unshare",	1,	0,	OPT_unshare },
-	{ "unshare-ops",1,	0,	OPT_unshare_ops },
-	{ "urandom",	1,	0,	OPT_urandom },
-	{ "urandom-ops",1,	0,	OPT_urandom_ops },
 	{ "vdso",	1,	0,	OPT_vdso },
 	{ "vdso-ops",	1,	0,	OPT_vdso_ops },
 	{ "vdso-func",	1,	0,	OPT_vdso_func },
