@@ -47,6 +47,7 @@ static void stress_nice_delay(void)
  */
 static int stress_nice(const stress_args_t *args)
 {
+	const bool cap_sys_nice = stress_check_capability(SHIM_CAP_SYS_NICE);
 #if defined(HAVE_SETPRIORITY)
 	int max_prio, min_prio;
 
@@ -78,9 +79,34 @@ static int stress_nice(const stress_args_t *args)
 		if (pid == 0) {
 			int i;
 
+			/*
+			 *  Test if calling process has CAP_SYS_NICE
+			 *  capability then only it can increase
+			 *  its priority by decreasing nice value
+			 */
+			if (!cap_sys_nice) {
+				(void)shim_nice(-1);
+			}
+
 			/* Child */
 			(void)setpgid(0, g_pgrp);
 			stress_parent_died_alarm();
+			(void)sched_settings_apply(true);
+
+#if defined(HAVE_SETPRIORITY)
+			/*
+			 *  Exercise illegal maximum priority
+			 *  to get more kernel test coverage
+			 */
+			(void)setpriority(PRIO_PROCESS, 0, max_prio + 1);
+
+			/*
+			 *  Exercise setpriority calls that uses illegal
+			 *  arguments to get more kernel test coverage
+			 */
+			(void)setpriority(INT_MIN, 0, max_prio - 1);
+			(void)setpriority(INT_MAX, 0, max_prio - 1);
+#endif
 
 			switch (which) {
 #if defined(HAVE_SETPRIORITY)
@@ -99,7 +125,13 @@ static int stress_nice(const stress_args_t *args)
 				for (i = -19; i < 20; i++) {
 					int ret;
 
-					ret = nice(1);
+					/*
+					 *  Invalid nice syscall with invalid
+					 *  inc argument and ignoring failure
+					 */
+					(void)shim_nice(INT_MAX);
+
+					ret = shim_nice(1);
 					if (ret == 0)
 						stress_nice_delay();
 					inc_counter(args);
