@@ -71,7 +71,8 @@ static void *semaphore_posix_thrash(void *arg)
 			int value;
 
 			if (sem_getvalue(&sem, &value) < 0)
-				pr_fail("sem_getvalue");
+				pr_fail("%s: sem_getvalue failed, errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 
 			if (i & 1) {
 				if (sem_trywait(&sem) < 0) {
@@ -79,7 +80,8 @@ static void *semaphore_posix_thrash(void *arg)
 					    errno == EAGAIN)
 						continue;
 					if (errno != EINTR)
-						pr_fail_dbg("sem_trywait");
+						pr_fail("%s: sem_trywait failed, errno=%d (%s)\n",
+							args->name, errno, strerror(errno));
 					break;
 				}
 			} else {
@@ -98,13 +100,15 @@ static void *semaphore_posix_thrash(void *arg)
 					    errno == ETIMEDOUT)
 						continue;
 					if (errno != EINTR)
-						pr_fail_dbg("sem_timedwait");
+						pr_fail("%s: sem_timedwait failed, errno=%d (%s)\n",
+							args->name, errno, strerror(errno));
 					break;
 				}
 			}
 			inc_counter(args);
 			if (sem_post(&sem) < 0) {
-				pr_fail_dbg("sem_post");
+				pr_fail("%s: sem_post failed, errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 				break;
 			}
 			if (stress_mwc1())
@@ -151,7 +155,8 @@ static int stress_sem(const stress_args_t *args)
 		p_ret[i] = pthread_create(&pthreads[i], NULL,
                                 semaphore_posix_thrash, (void *)&p_args);
 		if ((p_ret[i]) && (p_ret[i] != EAGAIN)) {
-			pr_fail_errno("pthread create", p_ret[i]);
+			pr_fail("%s: pthread create failed, errno=%d (%s)\n",
+				args->name, p_ret[i], strerror(p_ret[i]));
 			break;
 		}
 		if (!keep_stressing_flag())
@@ -166,7 +171,7 @@ static int stress_sem(const stress_args_t *args)
 
 	/* Wait for termination */
 	while (keep_stressing())
-		(void)shim_usleep(100000);
+		pause();
 
 	for (i = 0; i < semaphore_posix_procs; i++) {
 		int ret;
