@@ -31,6 +31,8 @@
 
 #define MSGVEC_SIZE		(4)
 
+#define PROC_CONG_CTRLS		"/proc/sys/net/ipv4/tcp_allowed_congestion_control"
+
 typedef struct {
 	const char *optname;
 	int	   opt;
@@ -103,7 +105,7 @@ static int stress_set_socket_type(const char *opt)
 		{ NULL,		0 }
 	};
 
-	int i;
+	size_t i;
 
 	for (i = 0; socket_type[i].typename; i++) {
 		if (!strcmp(opt, socket_type[i].typename)) {
@@ -151,6 +153,68 @@ static int stress_set_socket_domain(const char *name)
 	return ret;
 }
 
+/*
+ *  stress_free_congestion_controls()
+ *	free congestion controls array
+ */
+static void stress_free_congestion_controls(char *ctrls[], const size_t n)
+{
+	size_t i;
+
+	if (!ctrls)
+		return;
+
+	for (i = 0; i < n; i++)
+		free(ctrls[i]);
+
+	free(ctrls);
+}
+
+/*
+ *  stress_get_congestion_controls()
+ *	get congestion controls, currently only for AF_INET. ctrls is a
+ *	pointer to an array of pointers to available congestion control names -
+ *	the array is allocated by this function, or NULL if it fails. Returns
+ *	the number of congestion controls, 0 if none found.
+ */
+static size_t stress_get_congestion_controls(const int socket_domain, char **ctrls[])
+{
+	char buf[4096], *ptr, *ctrl;
+	char **array = NULL;
+	size_t n_ctrls;
+
+	*ctrls = NULL;
+
+	if (socket_domain != AF_INET)
+		return 0;
+
+	if (system_read(PROC_CONG_CTRLS, buf, sizeof(buf)) < 0)
+		return 0;
+
+	for (n_ctrls = 0, ptr = buf; (ctrl = strtok(ptr, " ")) != NULL; ptr = NULL) {
+		char **tmp, *newline = strchr(ctrl, '\n');
+
+		if (newline)
+			*newline = '\0';
+
+		tmp = realloc(array , (sizeof(*array)) * (n_ctrls + 1));
+		if (!tmp) {
+			stress_free_congestion_controls(array, n_ctrls);
+			return 0;
+		}
+		array = tmp;
+		array[n_ctrls] = strdup(ctrl);
+		if (!array[n_ctrls]) {
+			stress_free_congestion_controls(array, n_ctrls);
+			return 0;
+		}
+		n_ctrls++;
+	}
+
+	*ctrls = array;
+	return n_ctrls;
+}
+
 static void stress_sock_ioctl(const int fd, const int socket_domain)
 {
 	(void)fd;
@@ -257,11 +321,15 @@ static void stress_sock_client(
 	const int socket_domain)
 {
 	struct sockaddr *addr;
+	size_t n_ctrls;
+	char **ctrls;
 
 	(void)setpgid(0, g_pgrp);
 	stress_parent_died_alarm();
 	(void)sched_settings_apply(true);
 
+	n_ctrls = stress_get_congestion_controls(socket_domain, &ctrls);
+
 	do {
 		char buf[SOCKET_BUF];
 		int fd;
@@ -302,21 +370,47 @@ retry:
 			goto retry;
 		}
 
+#if defined(TCP_CONGESTION)
+			/*
+			 *  Randomly set congestion control
+			 */
+			if (n_ctrls > 0) {
+				const int idx = stress_mwc16() % n_ctrls;
+				const char *control = ctrls[idx];
+				char name[256];
+				socklen_t len;
+
+				len = (socklen_t)strlen(ctrls[idx]);
+				(void)setsockopt(fd, IPPROTO_TCP, TCP_CONGESTION, control, len);
+				len = (socklen_t)sizeof(name);
+				(void)getsockopt(fd, IPPROTO_TCP, TCP_CONGESTION, name, &len);
+			}
+#endif
 #if defined(IP_MTU)
 			{
-				int mtu;
-				socklen_t optlen = sizeof(mtu);
+				int ret, mtu;
+				socklen_t optlen;
 
-				(void)getsockopt(fd, IPPROTO_IP, IP_MTU,
+				optlen = sizeof(mtu);
+				ret = getsockopt(fd, IPPROTO_IP, IP_MTU,
 					&mtu, &optlen);
+				if (ret == 0) {
+					optlen = sizeof(mtu);
+					ret = setsockopt(fd, IPPROTO_IP, IP_MTU,
+						&mtu, optlen);
+				}
+				(void)ret;
 			}
 #endif
 #if defined(IP_TOS) && defined(IPTOS_THROUGHPUT)
 			{
 				char tos = IPTOS_THROUGHPUT;
+				socklen_t optlen = sizeof(tos);
 
 				(void)setsockopt(fd, IPPROTO_IP, IP_TOS,
-					&tos, sizeof(tos));
+					&tos, optlen);
+				(void)getsockopt(fd, IPPROTO_IP, IP_TOS,
+					&tos, &optlen);
 			}
 #endif
 #if defined(SO_INCOMING_CPU)
@@ -328,6 +422,114 @@ retry:
 					&cpu, &optlen);
 			}
 #endif
+			if (socket_domain == AF_INET || socket_domain == AF_INET6) {
+				int val, ret;
+				socklen_t optlen;
+
+				(void)val;
+				(void)ret;
+				(void)optlen;
+
+#if defined(TCP_NODELAY)
+				optlen = sizeof(val);
+				ret = getsockopt(fd, IPPROTO_TCP, TCP_NODELAY, &val, &optlen);
+				if (ret == 0) {
+					optlen = sizeof(val);
+					ret = setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, &val, optlen);
+				}
+				(void)ret;
+#endif
+#if defined(TCP_CORK)
+				optlen = sizeof(val);
+				ret = getsockopt(fd, IPPROTO_TCP, TCP_CORK, &val, &optlen);
+				if (ret == 0) {
+					optlen = sizeof(val);
+					ret = setsockopt(fd, IPPROTO_TCP, TCP_CORK, &val, optlen);
+				}
+				(void)ret;
+#endif
+#if defined(TCP_DEFER_ACCEPT)
+				optlen = sizeof(val);
+				ret = getsockopt(fd, IPPROTO_TCP, TCP_DEFER_ACCEPT, &val, &optlen);
+				if (ret == 0) {
+					optlen = sizeof(val);
+					ret = setsockopt(fd, IPPROTO_TCP, TCP_DEFER_ACCEPT, &val, optlen);
+				}
+				(void)ret;
+#endif
+#if defined(TCP_KEEPCNT)
+				optlen = sizeof(val);
+				ret = getsockopt(fd, IPPROTO_TCP, TCP_KEEPCNT, &val, &optlen);
+				if (ret == 0) {
+					optlen = sizeof(val);
+					ret = setsockopt(fd, IPPROTO_TCP, TCP_KEEPCNT, &val, optlen);
+				}
+				(void)ret;
+#endif
+#if defined(TCP_KEEPIDLE)
+				optlen = sizeof(val);
+				ret = getsockopt(fd, IPPROTO_TCP, TCP_KEEPIDLE, &val, &optlen);
+				if (ret == 0) {
+					optlen = sizeof(val);
+					ret = setsockopt(fd, IPPROTO_TCP, TCP_KEEPIDLE, &val, optlen);
+				}
+				(void)ret;
+#endif
+#if defined(TCP_KEEPINTVL)
+				optlen = sizeof(val);
+				ret = getsockopt(fd, IPPROTO_TCP, TCP_KEEPINTVL, &val, &optlen);
+				if (ret == 0) {
+					optlen = sizeof(val);
+					ret = setsockopt(fd, IPPROTO_TCP, TCP_KEEPINTVL, &val, optlen);
+				}
+				(void)ret;
+#endif
+#if defined(TCP_LINGER2)
+				optlen = sizeof(val);
+				ret = getsockopt(fd, IPPROTO_TCP, TCP_LINGER2, &val, &optlen);
+				if (ret == 0) {
+					optlen = sizeof(val);
+					ret = setsockopt(fd, IPPROTO_TCP, TCP_LINGER2, &val, optlen);
+				}
+				(void)ret;
+#endif
+#if defined(TCP_MAXSEG)
+				optlen = sizeof(val);
+				ret = getsockopt(fd, IPPROTO_TCP, TCP_MAXSEG, &val, &optlen);
+				if (ret == 0) {
+					optlen = sizeof(val);
+					ret = setsockopt(fd, IPPROTO_TCP, TCP_MAXSEG, &val, optlen);
+				}
+				(void)ret;
+#endif
+#if defined(TCP_SYNCNT)
+				optlen = sizeof(val);
+				ret = getsockopt(fd, IPPROTO_TCP, TCP_SYNCNT, &val, &optlen);
+				if (ret == 0) {
+					optlen = sizeof(val);
+					ret = setsockopt(fd, IPPROTO_TCP, TCP_SYNCNT, &val, optlen);
+				}
+				(void)ret;
+#endif
+#if defined(TCP_USER_TIMEOUT)
+				optlen = sizeof(val);
+				ret = getsockopt(fd, IPPROTO_TCP, TCP_USER_TIMEOUT, &val, &optlen);
+				if (ret == 0) {
+					optlen = sizeof(val);
+					ret = setsockopt(fd, IPPROTO_TCP, TCP_USER_TIMEOUT, &val, optlen);
+				}
+				(void)ret;
+#endif
+#if defined(TCP_WINDOW_CLAMP)
+				optlen = sizeof(val);
+				ret = getsockopt(fd, IPPROTO_TCP, TCP_WINDOW_CLAMP, &val, &optlen);
+				if (ret == 0) {
+					optlen = sizeof(val);
+					ret = setsockopt(fd, IPPROTO_TCP, TCP_WINDOW_CLAMP, &val, optlen);
+				}
+				(void)ret;
+#endif
+			}
 
 		do {
 			ssize_t n = 0;
@@ -446,6 +648,8 @@ retry:
 	}
 #endif
 	/* Inform parent we're all done */
+	stress_free_congestion_controls(ctrls, n_ctrls);
+
 	(void)kill(getppid(), SIGALRM);
 }
 
@@ -479,6 +683,7 @@ static int stress_sock_server(
 		rc = EXIT_FAILURE;
 		goto die;
 	}
+
 	if ((fd = socket(socket_domain, socket_type, 0)) < 0) {
 		rc = exit_status(errno);
 		pr_fail("%s: socket failed, errno=%d (%s)\n",
@@ -543,6 +748,7 @@ static int stress_sock_server(
 			struct mmsghdr msgvec[MSGVEC_SIZE];
 			unsigned int msg_len = 0;
 #endif
+
 			len = sizeof(saddr);
 			if (getsockname(fd, &saddr, &len) < 0) {
 				pr_fail("%s: getsockname failed, errno=%d (%s)\n",
