@@ -42,6 +42,11 @@ static int stress_sysinfo(const stress_args_t *args)
 {
 	int n_mounts;
 	char *mnts[128];
+#if defined(HAVE_SYS_SYSINFO_H) &&	\
+    defined(HAVE_SYSINFO) &&		\
+    defined(HAVE_SYS_STATFS_H)
+	const int bad_fd = stress_get_bad_fd();
+#endif
 
 	(void)memset(mnts, 0, sizeof(mnts));
 
@@ -67,7 +72,8 @@ static int stress_sysinfo(const stress_args_t *args)
 
 			ret = sysinfo(&sysinfo_buf);
 			if ((ret < 0) && (g_opt_flags & OPT_FLAGS_VERIFY))
-			 	pr_fail_err("sysinfo");
+			 	pr_fail("%s: sysinfo failed, errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
 
 			check_do_run();
 
@@ -91,16 +97,29 @@ static int stress_sysinfo(const stress_args_t *args)
 					if (errno != ENOSYS &&
 					    errno != EOVERFLOW &&
 					    errno != EACCES) {
-						pr_fail("%s: statfs on %s "
-							"failed: errno=%d (%s)\n",
+						pr_fail("%s: statfs on %s failed: errno=%d (%s)\n",
 							args->name, mnts[i], errno,
 							strerror(errno));
 					}
 				}
 
+				/*
+				 *  Exercise invalid mount point
+				 */
+				ret = statfs("/invalid_stress_ng", &statfs_buf);
+				(void)ret;
+
 				fd = open(mnts[i], O_RDONLY | O_DIRECTORY);
 				if (fd < 0)
 					continue;
+#if defined(FS_IOC_GETFSLABEL) && defined(FSLABEL_MAX)
+				{
+					char label[FSLABEL_MAX];
+
+					ret = ioctl(fd, FS_IOC_GETFSLABEL, label);
+					(void)ret;
+				}
+#endif
 
 				ret = fstatfs(fd, &statfs_buf);
 				(void)close(fd);
@@ -110,12 +129,16 @@ static int stress_sysinfo(const stress_args_t *args)
 					if (errno != ENOSYS &&
 					    errno != EOVERFLOW &&
 					    errno != EACCES) {
-						pr_fail("%s: fstatfs on %s "
-							"failed: errno=%d (%s)\n",
+						pr_fail("%s: fstatfs on %s failed: errno=%d (%s)\n",
 							args->name, mnts[i], errno,
 							strerror(errno));
 					}
 				}
+				/*
+				 *  Exercise invalid fd
+				 */
+				ret = fstatfs(bad_fd, &statfs_buf);
+				(void)ret;
 			}
 		}
 #endif
@@ -139,8 +162,7 @@ static int stress_sysinfo(const stress_args_t *args)
 					if (errno != EINVAL &&
 					    errno != EFAULT &&
 					    errno != ENOSYS) {
-						pr_fail("%s: ustat on %s "
-							"failed: errno=%d (%s)\n",
+						pr_fail("%s: ustat on %s failed: errno=%d (%s)\n",
 							args->name, mnts[i], errno,
 							strerror(errno));
 					}
@@ -169,12 +191,16 @@ static int stress_sysinfo(const stress_args_t *args)
 					if (errno != ENOSYS &&
 					    errno != EOVERFLOW &&
 					    errno != EACCES) {
-						pr_fail("%s: statvfs on %s "
-							"failed: errno=%d (%s)\n",
+						pr_fail("%s: statvfs on %s failed: errno=%d (%s)\n",
 							args->name, mnts[i], errno,
 							strerror(errno));
 					}
 				}
+				/*
+				 *  Exercise invalid mount point
+				 */
+				ret = statvfs("/invalid_stress_ng", &statvfs_buf);
+				(void)ret;
 			}
 		}
 #endif
@@ -182,7 +208,8 @@ static int stress_sysinfo(const stress_args_t *args)
 		check_do_run();
 		clk = times(&tms_buf);
 		if ((clk == (clock_t)-1) && (g_opt_flags & OPT_FLAGS_VERIFY)) {
-			 pr_fail_err("times");
+			 pr_fail("%s: times failed, errno=%d (%s)\n",
+				args->name, errno, strerror(errno));
 		}
 		inc_counter(args);
 	} while (keep_stressing());
