@@ -57,10 +57,14 @@ static const stress_help_t help[] = {
 static void check_unshare(const stress_args_t *args, int flags, const char *flags_name)
 {
 	int rc;
+
 	rc = shim_unshare(flags);
-	if ((rc < 0) && (errno != EPERM) && (errno != EINVAL)) {
-		pr_fail("%s: unshare(%s) failed, "
-			"errno=%d (%s)\n", args->name, flags_name,
+	if ((rc < 0) &&
+            (errno != EPERM) &&
+            (errno != EINVAL) &&
+            (errno != ENOSPC)) {
+		pr_fail("%s: unshare(%s) failed, errno=%d (%s)\n",
+			args->name, flags_name,
 			errno, strerror(errno));
 	}
 }
@@ -117,6 +121,7 @@ static int stress_unshare(const stress_args_t *args)
 				/* Child */
 				(void)setpgid(0, g_pgrp);
 				stress_parent_died_alarm();
+				(void)sched_settings_apply(true);
 
 				/* Make sure this is killable by OOM killer */
 				stress_set_oom_adjustment(args->name, true);
